@@ -104,33 +104,38 @@ sub import {
   my ($class, $caller) = (shift, caller);
   return unless my @flags = @_;
 
-  # Base
-  if ($flags[0] eq '-base') { $flags[0] = $class }
-
-  # Role
-  if ($flags[0] eq '-role') {
-    Carp::croak 'Role::Tiny 2.000001+ is required for roles' unless ROLES;
-    Mojo::Util::monkey_patch($caller, 'has', sub { attr($caller, @_) });
-    eval "package $caller; use Role::Tiny; 1" or die $@;
-  }
-
-  # Module and not -strict
-  elsif ($flags[0] !~ /^-/) {
-    no strict 'refs';
-    require(Mojo::Util::class_to_path($flags[0])) unless $flags[0]->can('new');
-    push @{"${caller}::ISA"}, $flags[0];
-    Mojo::Util::monkey_patch($caller, 'has', sub { attr($caller, @_) });
-  }
-
   # Mojo modules are strict!
   $_->import for qw(strict warnings utf8);
   feature->import(':5.10');
 
-  # Signatures (Perl 5.20+)
-  if (($flags[1] || '') eq '-signatures') {
-    Carp::croak 'Subroutine signatures require Perl 5.20+' if $] < 5.020;
-    require experimental;
-    experimental->import('signatures');
+  while (my $flag = shift @flags) {
+
+    # Base
+    if ($flag eq '-base') { push @flags, $class }
+
+    # Role
+    elsif ($flag eq '-role') {
+      Carp::croak 'Role::Tiny 2.000001+ is required for roles' unless ROLES;
+      Mojo::Util::monkey_patch($caller, 'has', sub { attr($caller, @_) });
+      eval "package $caller; use Role::Tiny; 1" or die $@;
+    }
+
+    # Signatures (Perl 5.20+)
+    elsif ($flag eq '-signatures') {
+      Carp::croak 'Subroutine signatures require Perl 5.20+' if $] < 5.020;
+      require experimental;
+      experimental->import('signatures');
+    }
+
+    # Module
+    elsif ($flag !~ /^-/) {
+      no strict 'refs';
+      require(Mojo::Util::class_to_path($flag)) unless $flag->can('new');
+      push @{"${caller}::ISA"}, $flag;
+      Mojo::Util::monkey_patch($caller, 'has', sub { attr($caller, @_) });
+    }
+
+    elsif ($flag ne '-strict') { Carp::croak "Unsupported flag: $flag" }
   }
 }
 
@@ -242,7 +247,7 @@ L<Role::Tiny> (2.000001+).
   use Role::Tiny;
   sub has { Mojo::Base::attr(__PACKAGE__, @_) }
 
-On Perl 5.20+ you can also append a C<-signatures> flag to all four forms and
+On Perl 5.20+ you can also use the C<-signatures> flag with all four forms and
 enable support for L<subroutine signatures|perlsub/"Signatures">.
 
   # Also enable signatures
