@@ -56,7 +56,7 @@ sub _default {
   my ($time, $level) = (shift, shift);
   my ($s, $m, $h, $day, $month, $year) = localtime $time;
   $time = sprintf '%04d-%02d-%02d %02d:%02d:%08.5f', $year + 1900, $month + 1,
-    $day, $h, $m, "$s." . (split /\./, $time)[1];
+    $day, $h, $m, "$s." . ((split /\./, $time)[1] // 0);
   return "[$time] [$$] [$level] " . join "\n", @_, '';
 }
 
@@ -195,7 +195,7 @@ following new ones.
 
 =head2 append
 
-  $log->append("[Thu May 15 17:47:04 2014] [info] I ♥ Mojolicious\n");
+  $log->append("[2018-11-08 14:20:13.77168] [28320] [info] I ♥ Mojolicious\n");
 
 Append message to L</"handle">.
 
